@@ -575,7 +575,12 @@ load_scalar(perl_yaml_loader_t *loader)
 
     if (style == YAML_PLAIN_SCALAR_STYLE && looks_like_number(scalar) ) {
         /* numify */
-        SvIV_please(scalar);
+        if (SvNV(scalar) == SvIV(scalar)) {
+            SvIOK_only(scalar);
+        }
+        else {
+            SvNOK_only(scalar);
+        }
     }
 
     (void)sv_utf8_decode(scalar);
